quantizationtools.QEvent
========================

.. abjad-lineage:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent

.. autoclass:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.index
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEvent.QEvent.QEvent.__setstate__
   :noindex:
